@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,9 +40,7 @@
 #include <bf_svtools/zforlist.hxx>
 #endif
 
-#ifndef _TOOLS_TENCCVT_HXX
 #include <tools/tenccvt.hxx>
-#endif
 
 #include <float.h>
 #include <math.h>
@@ -1404,3 +1403,5 @@ using namespace ::com::sun::star;
            return true;
 /*N*/  }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
