@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -25,59 +26,33 @@
  *
  ************************************************************************/
 
-#ifndef _COM_SUN_STAR_BEANS_PROPERTYATTRIBUTE_HPP_
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-#endif
-#ifndef _RTL_USTRBUF_HXX_ 
 #include <rtl/ustrbuf.hxx>
-#endif
 
-#ifndef _COMPHELPER_STLTYPES_HXX_ 
 #include <comphelper/stl_types.hxx>
-#endif
 
-#ifndef _SFXSTYLE_HXX
 #include <bf_svtools/style.hxx>
-#endif
 
-#ifndef _SVTOOLS_UNOIMAP_HXX
 #include <bf_svtools/unoimap.hxx>
-#endif
-#ifndef _SVTOOLS_UNOEVENT_HXX_
 #include <bf_svtools/unoevent.hxx>
-#endif
 
 #include <vcl/svapp.hxx>
 
-#ifndef _SFXSIDS_HRC
 #include <bf_sfx2/sfxsids.hrc>
-#endif
 #include <comphelper/extract.hxx>
 #include <bf_svx/unoshape.hxx>
 #include <bf_svx/svditer.hxx>
 #include <bf_svx/unoapi.hxx>
 
-#ifndef _SVDOPATH_HXX 
 #include <bf_svx/svdopath.hxx>
-#endif
 
-#ifndef _SVDOOLE2_HXX
 #include <bf_svx/svdoole2.hxx>
-#endif
-#ifndef _SVDOGRAF_HXX 
 #include <bf_svx/svdograf.hxx>
-#endif
-#ifndef _OUTLOBJ_HXX
 #include <bf_svx/outlobj.hxx>
-#endif
 
-#ifndef _SD_SPOUTLINER_HXX
 #include "sdoutl.hxx"
-#endif
 
-#ifndef _SDRESID_HXX
 #include "sdresid.hxx"
-#endif
 
 #include "anminfo.hxx"
 #include "unohelp.hxx"
@@ -106,7 +81,6 @@ namespace binfilter {
  #endif
 #endif
 
-using namespace ::vos;
 using namespace ::rtl;
 using namespace ::com::sun::star;
 
@@ -325,7 +299,7 @@ uno::Sequence< uno::Type > SAL_CALL SdXShape::getTypes()
 // XPropertyState
 beans::PropertyState SAL_CALL SdXShape::getPropertyState( const OUString& PropertyName ) throw( beans::UnknownPropertyException, uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     if( maPropSet.getPropertyMapEntry(PropertyName) )
     {
@@ -343,7 +317,7 @@ beans::PropertyState SAL_CALL SdXShape::getPropertyState( const OUString& Proper
 
 void SAL_CALL SdXShape::setPropertyToDefault( const OUString& PropertyName ) throw( beans::UnknownPropertyException, uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     if( maPropSet.getPropertyMapEntry(PropertyName) )
     {
@@ -357,7 +331,7 @@ void SAL_CALL SdXShape::setPropertyToDefault( const OUString& PropertyName ) thr
 
 uno::Any SAL_CALL SdXShape::getPropertyDefault( const OUString& aPropertyName ) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     if( maPropSet.getPropertyMapEntry(aPropertyName) )
     {
@@ -412,7 +386,7 @@ uno::Any SAL_CALL SdXShape::getPropertyDefault( const OUString& aPropertyName )
 void SAL_CALL SdXShape::setPropertyValue( const ::rtl::OUString& aPropertyName, const ::com::sun::star::uno::Any& aValue )
     throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::beans::PropertyVetoException, ::com::sun::star::lang::IllegalArgumentException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     const SfxItemPropertyMap* pMap = maPropSet.getPropertyMapEntry(aPropertyName);
 
@@ -616,7 +590,7 @@ void SAL_CALL SdXShape::setPropertyValue( const ::rtl::OUString& aPropertyName,
 ::com::sun::star::uno::Any SAL_CALL SdXShape::getPropertyValue( const ::rtl::OUString& PropertyName )
     throw(::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::lang::WrappedTargetException, ::com::sun::star::uno::RuntimeException)
 {
-    OGuard aGuard( Application::GetSolarMutex() );
+    SolarMutexGuard aGuard;
 
     uno::Any aRet;
 
@@ -1752,3 +1726,5 @@ uno::Sequence< OUString > SAL_CALL SdUnoEventsAccess::getSupportedServiceNames(
     return aStr;
 }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
